API Reference
=============

This section documents the public Python API. Internal backbones such as
``beats`` and ``passt`` are intentionally excluded.

Core API
--------

.. automodule:: deepaudiox
   :members: AudioClassifier, AudioClassifierConstructor, AudioClassificationDataset, Backbone, BackboneConstructor, Evaluator, Trainer, BACKBONES, POOLING, audio_classification_dataset_from_dictionary, audio_classification_dataset_from_dir
   :undoc-members:
